@@ -3,7 +3,8 @@ from typing import Union, TYPE_CHECKING, Tuple, Dict, Set, List
 
 from numpy import zeros
 
-from mewpy.solvers import get_default_solver, solvers
+from mewpy.solvers import get_default_solver
+from mewpy.solvers.sglobal import __MEWPY_solvers__ as solvers
 from mewpy.solvers.solution import Solution
 from mewpy.solvers.solver import Solver, VarType
 from mewpy.mew.solution import ModelSolution
@@ -238,7 +239,7 @@ class LinearProblem(LinearProblemInterface):
         return self._model
 
     @property
-    def solver(self) -> Union[Solver]:
+    def solver(self) -> Solver:
         """
         mewpy solver instance for this linear problem. It contains an interface for the concrete solver
 
