@@ -50,6 +50,7 @@ class CBModelContainer(ModelContainer):
         rxn = self.model.reactions[r_id]
         res = {'id': r_id, 'name': rxn.name, 'lb': rxn.lb, 'ub': rxn.ub, 'stoichiometry': rxn.stoichiometry}
         res['gpr'] = str(rxn.gpr) if rxn.gpr is not None else None
+        res['annotations'] = rxn.metadata
         return AttrDict(res)
 
     @property
@@ -59,7 +60,7 @@ class CBModelContainer(ModelContainer):
     def get_gene(self, g_id):
         g = self.model.genes[g_id]
         gr = self.get_gene_reactions()
-        r = gr[g_id]
+        r = gr.get(g_id,[])
         res = {'id': g_id, 'name': g.name, 'reactions': r}
         return AttrDict(res)
 
@@ -79,7 +80,7 @@ class CBModelContainer(ModelContainer):
     def get_compartment(self, c_id):
         c = self.model.compartments[c_id]
         res = {'id': c_id, 'name': c.name, 'external': c.external}
-        return res
+        return AttrDict(res)
 
     def get_exchange_reactions(self):
         return self.model.get_exchange_reactions()
@@ -176,6 +177,10 @@ class Simulation(CBModelContainer, Simulator):
         for r_id, bounds in self._constraints.items():
             self._set_model_reaction_bounds(r_id, bounds)
 
+        # if modifications on the envirenment are permited
+        # during simulations
+        self._allow_env_changes = False
+
     def _set_model_reaction_bounds(self, r_id, bounds):
         if isinstance(bounds, tuple):
             lb = bounds[0]
@@ -247,8 +252,13 @@ class Simulation(CBModelContainer, Simulator):
         meta.metadata['FORMULA'] = formula
         self.model.add_metabolite(meta)
 
-    def add_reaction(self, rxn_id, stoichiometry, lb=ModelConstants.REACTION_LOWER_BOUND,
-                     ub=ModelConstants.REACTION_UPPER_BOUND, replace=True, **kwargs):
+    def add_gene(self,id,name):
+        from reframed.core.cbmodel import Gene
+        g = Gene(id,name)
+        self.model.add_gene(g)
+
+    def add_reaction(self, rxn_id,  name=None, stoichiometry=None, lb=ModelConstants.REACTION_LOWER_BOUND,
+                     ub=ModelConstants.REACTION_UPPER_BOUND, gpr= None, replace=True, **kwargs):
         """Adds a reaction to the model
 
         Args:
@@ -258,7 +268,7 @@ class Simulation(CBModelContainer, Simulator):
             Defaults to True.
         """
         from reframed.core.cbmodel import CBReaction
-        reaction = CBReaction(rxn_id, stoichiometry=stoichiometry, lb=lb, ub=ub)
+        reaction = CBReaction(rxn_id, stoichiometry=stoichiometry,name=name, lb=lb, ub=ub, gpr_association=gpr)
         self.model.add_reaction(reaction, replace=replace)
 
     def remove_reaction(self, r_id):
@@ -433,9 +443,12 @@ class Simulation(CBModelContainer, Simulator):
 
         simul_constraints = OrderedDict()
         if constraints:
-            simul_constraints.update({k: v for k, v in constraints.items()
-                                      if k not in list(self._environmental_conditions.keys())})
-
+            if not self._allow_env_changes:
+                simul_constraints.update({k: v for k, v in constraints.items()
+                                        if k not in list(self._environmental_conditions.keys())})
+            else:
+                simul_constraints.update(constraints)
+    
         a_solver = solver
         if not self._reset_solver and not a_solver:
             if self.solver is None:
